Module: Kitchen::Driver::Oci::Instance::CommonLaunchDetails

Included in:
Kitchen::Driver::Oci::Instance
Defined in:
lib/kitchen/driver/oci/instance/common.rb

Overview

Setter methods that populate launch details common to all instance models.

Author:

  • Justin Steele <justin.steele@oracle.com>

Instance Method Summary collapse

Instance Method Details

#availability_domainObject

Assigns the availability_domain to the launch details.



33
34
35
# File 'lib/kitchen/driver/oci/instance/common.rb', line 33

def availability_domain
  launch_details.availability_domain = config[:availability_domain]
end

#compartment_idObject

Assigns the ocid of the compartment to the launch details.



28
29
30
# File 'lib/kitchen/driver/oci/instance/common.rb', line 28

def compartment_id
  launch_details.compartment_id = oci.compartment
end

#defined_tagsObject

Assigns the defined_tags to the launch details.



38
39
40
# File 'lib/kitchen/driver/oci/instance/common.rb', line 38

def defined_tags
  launch_details.defined_tags = config[:defined_tags]
end

#freeform_tagsObject

Assigns the freeform_tags to the launch_details.



48
49
50
# File 'lib/kitchen/driver/oci/instance/common.rb', line 48

def freeform_tags
  launch_details.freeform_tags = process_freeform_tags
end

#shapeObject

Assigns the shape to the launch_details.



43
44
45
# File 'lib/kitchen/driver/oci/instance/common.rb', line 43

def shape
  launch_details.shape = config[:shape]
end